
# coding=cp1251
"""
       /  esp32_HD 
 REST API       ,   
:
ip - IP  (   ,  192.168.0.44)
filename -     .    ,  esp32_hd.log
-p -    ,     - 5 
-- -      .   ,    -  

      log_keys
"""
import csv, json, sys
import time
import argparse
import requests
from requests.exceptions import HTTPError

log_keys = ['uptime', 'MainMode', 'MainStatus', 'CurVolts', 'CurPower', 'SetPower', 'Alarm','sensors','klapans']

def openFile(filename, clr):
    try:
        return open(filename, "w" if clr!=None else "a")
    except Exception as e:
        sys.stderr.write('could not open file {}: {}\n'.format(filename, e))
        return None

def readHttp(ip):
    try:
        response = requests.get('http://'+ip+'/maininfo')
        response.raise_for_status()
    except HTTPError as http_err:
        print(f'HTTP error occurred: {http_err}')  # Python 3.6
    except Exception as err:
        print(f'Other error occurred: {err}')  # Python 3.6
    return response


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='esp32HD logger')
    parser.add_argument(
        "filename",
        nargs='?',
        help="filename of log [esp32_hd.log by default]",
        default="esp32_hd.log")
    parser.add_argument(
        "ip",
        nargs='?',
        help="IP esp32_hd [192.168.0.44 by default]",
        default='192.168.0.44')
    parser.add_argument('--c', action='store_const', help="clear file", const=1)
    parser.add_argument("-period", "-p", nargs='?', type=int, help="logging period,sec [5 sec by default]", const=5)
    args = parser.parse_args()
    print(f"IP:{args.ip} file:{args.filename} period:{args.period} sec")

    if args.ip is None:
        parser.error('IP must be specifyied')
        exit()
    
    if args.filename is None:
        parser.error('filename  must be specifyied')
        exit()
        
    if (not readHttp(args.ip)):
        exit()
    outputFile = openFile(args.filename,args.c)
    if args.c!=None:
        head_printed = 0
    else:
        head_printed = 1
    try:
      while (True):
            r = readHttp(args.ip)
            if (not r): continue
            data = r.json()
            print(f"{data.get('uptime')}: {data.get('MainModeStr')}/{data.get('MainStatusStr')}")
            
            if head_printed==0:
                for i in log_keys:
                    if i=='sensors':
                        for s0 in data.get(i):
                            outputFile.write(f"T{s0.get('type_str')};")
                    else: 
                        if i=='klapans':
                            for k0 in data.get(i):
                                outputFile.write(f"V{k0.get('id')};")
                        else:
                            outputFile.write(f"{i};")
                outputFile.write('\n')
                head_printed = 1
            for x in log_keys:
                if x=='sensors':
                    for s in data.get(x):
                        outputFile.write(f"{s.get('temp')};")
                else:
                    if x=='klapans':
                        for k in data.get(x):
                            outputFile.write(f"{k.get('is_open')};")
                    else:
                        v = data.get(x)
                        outputFile.write(f"{v};")
            outputFile.write('\n')
            outputFile.flush()
            time.sleep(args.period)
    except Exception as e:
      outputFile.close()
      print('stop')
      print('Error:{}'.format(str(e)))
    outputFile.close()
    print('end of work')
